


******

Bravo!  You have received a Mercantilism Diploma in "story_1" from   
the Simulated Parallel Science Universe Fictional Fantasy Orbital Convergence University   
International Air and Water Embassy Naturalization Department of the Mango Planet
(the planet that is one ellipse closer to the Sun than Earth's ellipse).    

You are now officially certified to perform "story_1" operations in your   
simulated parallel science universe fictional fantasy practice!    

Encore! Encore! Encore! Encore!

******


# story_1
for motion picture use, etc.   

---

## description
Welcome to reelity.

---

## obtain
`[xonsh] pip install story_1`

--

## tutorial
`[xonsh] story_1 tutorial`

---

## key generation
This can be found in the tutorial at "modules/EEC_448_2/tutorial"